/////////////////////////////////////////////////////////////////////////////////
// game.gs
// Users write here basic functions specific for their game. Also check the gamedef.gs
// Advanced users may need to adjust other files as well.
//
// Here are the callback functions that usually stay in this file:
//
// Initialization callbacks:
// RoomsSetNames, ObjectsSetNames, RoomSetCustomText, SaveUserData, LoadUserData, BeginNewGame
//
// Rooms interaction callbacks:
// UpdateRoom_RX_RY()			- called by HandlerGameUpdate while player is in room RX,RY (non-latent)
// AfterRoom_RX_RY()			- called by HandlerGameAfterUpdate while player is in room RX,RY (non-latent)
// OpenRoom_RX_RY()				- called by HandlerRoomOpen when room RX,RY is opened (non-latent)
// CloseRoom_RX_RY()			- called by HandlerRoomClose when room RX,RY is closed (non-latent)
// OutRoom_RX_RY()				- called by HandlerRoomOut when player wants to exit room RX,RY (can reposition player here) (non-latent)
//
// Objects interaction callbacks:
// PickupObject_ID()			- called when picking up item ID (latent)
// DropObject_ID()				- called when droping item ID (latent)
// ActionObject_ID()			- called when player hits ACTION key on object ID (latent)
// UseObject_ID( idx )			- called when player wants to use object idx (from inventory) over the ID object (from the map) (latent)
// CollideObject_ID_MODE()		- called when player collides with object ID in mode MODE (0=exit from collision, 1=just entered collision, 2=continuing to collide) (latent)
//
// Player callbacks:
// PlayerDeathMessage( death ) 	- called by PlayerLoseLife and sould just return the death message text. return "" for no death message box (latent)
// RespawnPlayer_DEATH()		- called by PlayerLoseLife for custom death respawns. DEATH is the value of player's P_DEATH property
//
// ID, RX, RY, MODE are to pe replaced with coresponding numbers
//
/////////////////////////////////////////////////////////////////////////////////

/////////////////////////////////////////////////////////////////////////////////
// Sets room names (non-latent)
// By default it loads them from the dizzy.nam file, using the RoomsLoadNames() function.
// You can also set the names for each room, by hand, with RoomSetName().
// Ex: RoomSetName( 1,1, "PRESS ACTION TO START" );
/////////////////////////////////////////////////////////////////////////////////
func RoomsSetNames()
{
	RoomsLoadNames(ROOM_NAMESFILE);
      RoomSetName( 0,0, "START" );
      RoomSetName( 1,0, "END" );

      RoomSetName( 35,29, "ZAOBLAQNIXY ZAMOK" );
      RoomSetName( 36,29, "ZAOBLAQNIXY ZAMOK" );
      RoomSetName( 37,29, "ZAOBLAQNIXY ZAMOK" );
      RoomSetName( 37,31, "BEZDONNIXY KOLODETS" );
      RoomSetName( 38,31, "SAD" );
      RoomSetName( 39,31, "POLE" );
      RoomSetName( 40,31, "DOM" );
      RoomSetName( 41,31, "LES" );
      RoomSetName( 42,31, "KRAY SVETA" );
      RoomSetName( 36,31, "REKA" );
      RoomSetName( 35,31, "ZAMOK" );
      RoomSetName( 39,30, "NEBO" );
      RoomSetName( 34,31, "ZAMOK" );
      RoomSetName( 33,31, "ZAMOK" );
      RoomSetName( 32,31, "ZAZERKALJE" );
      RoomSetName( 37,32, "BEZDONNIXY KOLODETS" );
      RoomSetName( 37,33, "BEZDONNIXY KOLODETS" );
      RoomSetName( 37,36, "BEZDONNIXY KOLODETS" );
      RoomSetName( 37,37, "BEZDONNIXY KOLODETS" );
      RoomSetName( 37,35, "STRANNIXY NOVIXY MIR" );
      RoomSetName( 36,35, "BOLOTO" );
      RoomSetName( 38,35, "BOLOTO" );
      RoomSetName( 35,35, "RAVNINA I KLADKA" );
      RoomSetName( 34,35, "SARAY" );
      RoomSetName( 39,29, "NEBO" );
      RoomSetName( 39,28, "NEBO" );
      RoomSetName( 39,27, "KOSMOS" );
      RoomSetName( 39,26, "VID NA LUNU" );
      RoomSetName( 40,26, "LUNA" );
      RoomSetName( 41,26, "ZDESJ KTO-TO BIXL" );
      RoomSetName( 42,26, "ZDESJ KTO-TO ESTJ" );
      RoomSetName( 43,26, "BAZA PRICEXLJTSEV" );
      RoomSetName( 44,26, "STANTSIXAJ" );
      RoomSetName( 45,26, "KRAY LUNIX" );
      RoomSetName( 8,31, "SKAZOQNIXY PORTAL" );
      RoomSetName( 31,31, "ZAZERKALJE" );
      RoomSetName( 30,31, "ZAZERKALJE" );
      RoomSetName( 29,31, "ZAZERKALJE" );

}

/////////////////////////////////////////////////////////////////////////////////
// Sets names to object items (non-latent)
// All items tht you might pick up and view in the inventory, must have names set.
// Use the ID you specified for the object in the map editor, to find the object.
// See ObjSetName() and ObjFind().
// Ex: ObjSetName(ObjFind(100),"BUCKET");
/////////////////////////////////////////////////////////////////////////////////
func ObjectsSetNames()
{
	// ...

   ObjSetName(ObjFind(130),"KREPKAAJ TROSTJ");
   ObjSetName(ObjFind(200),"PUSTOE VEDRO");
   ObjSetName(ObjFind(210),"VEDRO S VODOY");
   ObjSetName(ObjFind(140),"UVESISTIXY KAMENJ");
   ObjSetName(ObjFind(500),"SEREBRAJNIXYY KLUJQ");
   ObjSetName(ObjFind(180),"MACIXNNOE MASLO");
   ObjSetName(ObjFind(450),"ZOLOTOY KLUJQ");
   ObjSetName(ObjFind(100),"FASOLJ");
   ObjSetName(ObjFind(101),"SMAZOQNIXY APPARAT");
   ObjSetName(ObjFind(190),"MOLOTOK");
   ObjSetName(ObjFind(191),"KOVOJR");
   ObjSetName(ObjFind(195),"VOLCEXBNIXY KOVOJR");
   ObjSetName(ObjFind(160),"SKAFANDR");
   ObjSetName(ObjFind(22),"AJBLOKO");
   ObjSetName(ObjFind(14),"OSTRIXY CIXP");
   ObjSetName(ObjFind(12),"PINTSET");
   ObjSetName(ObjFind(18),"KLUJQ");
   ObjSetName(ObjFind(468),"NASTOYKA");
   ObjSetName(ObjFind(25),"WEXLEZNIXY LOM");
   ObjSetName(ObjFind(79),"QESNOK");
   ObjSetName(ObjFind(71),"KIRKA");
   ObjSetName(ObjFind(973),"TOPOR");
   ObjSetName(ObjFind(297),"KLUJQ");
   ObjSetName(ObjFind(406),"VIDEO-KAMERA");

}

/////////////////////////////////////////////////////////////////////////////////
// IN: int; rx; room x coordinate
// IN: int; ry; room y coordinate
// IN: int; idx; room custom text index (0-3)
// IN: ref; strref; string reference to the custom text
// Sets custom texts for each room (non-latent)
// There are 4 custom texts per room, that can be set from the map editor.
// They are saved by default in the ROOM_TEXTSFILE file (dizzy.rt)
// Each game receives these texts through this callback when the map is loaded
// and it can interpret them as it wants, for example to fill custom structures
// per each room, like ambient sounds, or any other things.
// Only non-empty strings are saved from the editor.
// This function uses string reference for speed.
/////////////////////////////////////////////////////////////////////////////////
func RoomSetCustomText( rx, ry, idx, refstr )
{
	// println("RCT: ",rx,",",ry,",",idx," = ",(*refstr));
	// ...
}

/////////////////////////////////////////////////////////////////////////////////
// IN: int; death; cause of death
// Returns the player death message. Called by PlayerLoseLife().
// Declare more death defines in gamedef.gs (like DEATH_INFIRE, or DEATH_BATS)
// and set them to hurt and kill objects or just set them in the player's 
// P_DEATH property, then return specific messages in this callback, 
// for each cacuse of death .
/////////////////////////////////////////////////////////////////////////////////
func PlayerDeathMessage( death )
{
	if(death==-1)					return "";
	// ...
	return "YOU HAVE DIED!";		// default
}

/////////////////////////////////////////////////////////////////////////////////
// IN: int; file; file handler
// OUT: int; return 0 if something has failed, or 1 if operation was successful
// Saves additional user data.
// Users can save here the additional data (like global GS9 variables) they might need to place in the saved game file.
// Called from SaveGame(). See LoadUserData().
// Ex: if(!gs_filewriteint(g_myvariable,file)) return 0;
/////////////////////////////////////////////////////////////////////////////////
func SaveUserData( file )
{
	// ...
	return 1;
}

/////////////////////////////////////////////////////////////////////////////////
// IN: int; file; file handler
// OUT: int; return 0 if something has failed, or 1 if operation was successful
// Load additional user data.
// Users can load here the additional data (like global GS9 variables) they saved before.
// They can also set various things, that depends on the just loaded data.
// For example, since the room's or object's names are not stored in the saved game, 
// if such a name is changed as the result of a solved puzzle, when the game is loaded, 
// it must be changed again, accordingly to the status of the puzzle.
// Called from LoadGame(). See SaveUserData(). 
// Ex: if(!gs_filereadint(&g_myvariable, file)) return 0;
/////////////////////////////////////////////////////////////////////////////////
func LoadUserData( file )
{
	// ...
	return 1;
}

/////////////////////////////////////////////////////////////////////////////////
// This function is called from MainMenu when a new game begins.
// Users must write here whatever they need their game to do, when it's started.
// For example here can be placed or called an intro sequence.
// In the end, the game must be unpaused, the player must be positioned where he must start, game music can be played, etc.
// In the Default Template this also opens a "Hello World!" message.
// Latent function.
/////////////////////////////////////////////////////////////////////////////////
func BeginNewGame()
{
	GameSet(G_PAUSE,0);							// unpause the game
	PlayerSet(P_DISABLE,0);						// enable player
	PlayerSetPos(PLAYER_BEGINX,PLAYER_BEGINY);	// set begin position
	MusicFade(0,1);								// set music fade options
	MusicPlay(MUSIC_DEFAULT);					// play default music

	// just a hello message
	Message(14,6,"DIZZI!",COLOR_MAGENTA,COLOR_GREEN);
	MessagePop();
        Message(10,6,"SKAZOQNOE\nPUTECEXSTVIE!",COLOR_MAGENTA,COLOR_GREEN);
	MessagePop();
}

/////////////////////////////////////////////////////////////////////////////////
// Interactions
/////////////////////////////////////////////////////////////////////////////////

// Brat
func ActionObject_1001()
{
idx = ObjFind(1001);
status = ObjGet(idx,O_STATUS);
	if(status==0)


	{
            Message1(10,4,"PRIVET, DIZZI,\nDAVAY OTDIXHATJ?");
		MessagePop();
		Message2(16,8,"NET, AJ ICUJ 30 MONET\nDLAJ SKAZOQNOGO\nPUTECEXSTVIAJ!");
		MessagePop();
		Message1(14,6,"SOVETUUJ TEBE\nZANAJTJSAJ\nSADOVODSTVOM!");
		MessagePop();
            ObjSet(idx,O_STATUS,1);

            idx = ObjFind(100);
            ObjSet(idx,O_DISABLE,0);
}
if(status==1)


	{
            Message1(10,4,"TIX NACOL\n30 MONET?");
		MessagePop();
		Message2(14,6,"NET ECOJ");
		MessagePop();

}
}

// Koroleva
func ActionObject_1011()
{
idx = ObjFind(1011);

	{
            Message1(10,4,"AJ CAHMATNAAJ\nKOROLEVA");
		MessagePop();

            ObjSet(idx,O_DISABLE,1);

            idx = ObjFind(195);
            ObjSet(idx,O_DISABLE,0);
}
}

// BABUCKA 1
func ActionObject_1021()
{
idx = ObjFind(1021);
status = ObjGet(idx,O_STATUS);
	if(status==0)

	{
            Message1(10,4,"PRIVET, DIZZI,\nDAVAY OTDIXHATJ?");
		MessagePop();
		Message2(16,8,"NET, AJ ICUJ 30 MONET\nDLAJ SKAZOQNOGO\nPUTECEXSTVIAJ!");
		MessagePop();

            ObjSet(idx,O_STATUS,1);
            ObjSet(idx,O_DISABLE,1);

}
}

// BABUCKA 2
func ActionObject_1020()
{
idx = ObjFind(1020);
status = ObjGet(idx,O_STATUS);
	if(status==0)

	{

InventorySub(idx);

            Message1(10,4,"DIZZI TOLKNUL\nBABUCKU");
		MessagePop();
            Message1(16,8,"NO ONA SPIT");
		MessagePop();
            ObjSet(idx,O_STATUS,1);
            ObjSet(idx,O_DISABLE,1);

            idx = BrushFind(1022);
            BrushSet (idx,B_DRAW,3);

GameCommand (CMD_REFRESH);

}
}


// KOLODETS

func UseObject_1030( idx )
{
if(ObjGet(idx,O_ID)==130) 
{
Message1(5,4, "ISPOLJZOVAV TROSTJ\nKAK RIXQAG"); 
MessagePop();
Message2(16,8,"DIZZI OTODVINUL\nKRIXCKU KOLODTSA");
MessagePop();
InventorySub(idx);
idx = BrushFind(1040);
BrushSet (idx,B_DRAW,0);
GameCommand (CMD_REFRESH);

}
else
{
DropObject(idx);
}
}


// VEDRO

func ActionObject_2000()
{
idx = OpenDialogInventory();
if (idx!=-1) UseObject(idx);
}

func UseObject_2000( idx )
{
if(ObjGet(idx,O_ID)==200)

	{

            Message1(10,4,"DIZZI NABRAL\nVEDRO VODIX");
		MessagePop();

InventorySub(idx);

 ObjSet(idx,O_DISABLE,1);

idx = ObjFind(210);
            ObjSet(idx,O_DISABLE,0);



GameCommand (CMD_REFRESH);
}
else
{
DropObject(idx);


}
}

// MUWIXK

func UseObject_1501( idx )
{

if(ObjGet(idx,O_ID)==468)

	{
            Message1(10,4,"AJ QTO-TO NACOL");
		MessagePop();
InventorySub(idx);
            ObjSet(idx,O_DISABLE,1);

   idx = ObjFind(101);
          ObjSet(idx,O_DISABLE,0);
GameCommand (CMD_REFRESH);

}
else
{
DropObject(idx);
}
}


// MUWIXK 2

func UseObject_407( idx )
{

if(ObjGet(idx,O_ID)==406)

	{
            Message1(10,4,"DIZZI OBMENAJL\nVIDEO-KAMERU");
		MessagePop();
        Message1(9,5,"NA KANISTRU BENZINA");
		MessagePop();
      Message1(10,4,"DIZZI ZAPRAVIL\nMOTORNUUJ LODKU");
		MessagePop();

InventorySub(idx);
            ObjSet(idx,O_DISABLE,1);

   idx = ObjFind(89);
           ObjSet(idx,O_DISABLE,0);
GameCommand (CMD_REFRESH);

}
else
{
DropObject(idx);
}
}


// STEB 1

func UseObject_4010( idx )

{
if(ObjGet(idx,O_ID)==100) 
{
Message2(16,8,"DIZZI POSADIL\nFASOLJ V NAVOZ");
MessagePop();

InventorySub(idx);

ObjSet(ObjFind(4010),O_STATUS,8);

GameCommand (CMD_REFRESH);
}

else

	if(idx==ObjFind(210) && ObjGet(ObjFind(4010),O_STATUS)!=5) 
	{
Message2(16,8,"DIZZI POLIL\nSAWEXNETS VODOY");
MessagePop();

InventorySub(idx);

idx = BrushFind(3000);
BrushSet (idx,B_DRAW,3);

idx = BrushFind(3001);
BrushSet (idx,B_DRAW,3);

idx = BrushFind(3002);
BrushSet (idx,B_DRAW,3);

idx = BrushFind(3003);
BrushSet (idx,B_DRAW,3);

idx = BrushFind(3004);
BrushSet (idx,B_DRAW,3);

GameCommand (CMD_REFRESH);
}

else
{
DropObject(idx);
}
}

//

func ActionObject_4010( idx )
{
	if(ObjGet(ObjFind(4010),O_STATUS)==0) // first time talk
	{
		Message2(3,8,"ZDESJ PLOHO PAHNET");
		MessagePop();
		ObjSet(ObjFind(4010),O_STATUS,5); // advance the talk status
	}
	else // next time
	{
		// open the inventory dialog and let the player select an item
		idx = OpenDialogInventory();
		if(idx!=-1)
		{
			// if an item was selected, call the defaut use function
			// it will also call the UseObject callback of the item
			UseObject(idx); 
		}
	}
}



// DVERJ 1

func UseObject_1750( idx )
{
if(ObjGet(idx,O_ID)==500) 
{
Message1(5,4, "DIZZI OTKRIXL\nDVERJ KLUJQOM"); 
MessagePop();
InventorySub(idx);
idx = BrushFind(1730);
BrushSet (idx,B_DRAW,0);
GameCommand (CMD_REFRESH);

}
else
{
DropObject(idx);
}
}

// ZERKALO

func UseObject_1850( idx )
{
if(ObjGet(idx,O_ID)==180) 
{
Message1(5,4, "DIZZI VIXLIL\nMASLO NA POL"); 
MessagePop();
Message2(16,8,"DVOYNIK\nPODSKOLJZNULSAJ\nI ISQEZ");
MessagePop();
InventorySub(idx);
idx = BrushFind(1840);
BrushSet (idx,B_DRAW,0);
idx = BrushFind(1830);
BrushSet (idx,B_DRAW,0);
idx = BrushFind(1820);
BrushSet (idx,B_DRAW,0);
idx = BrushFind(1810);
BrushSet (idx,B_DRAW,0);
idx = BrushFind(1800);
BrushSet (idx,B_DRAW,0);

idx = BrushFind(764);
BrushSet (idx,B_DRAW,2);

idx = BrushFind(763);
BrushSet (idx,B_DRAW,2);

            idx = ObjFind(333);
            ObjSet(idx,O_DISABLE,1);

            idx = ObjFind(332);
            ObjSet(idx,O_DISABLE,0);

GameCommand (CMD_REFRESH);

}
else
{
DropObject(idx);
}
}

// LIFT 1

func UseObject_2120( idx )
{
if(ObjGet(idx,O_ID)==297) 
{
Message1(5,4, "DIZZI ZAVOJL\nLIFT KLUJQOM"); 
MessagePop();

InventorySub(idx);
idx = BrushFind(2110);
BrushSet (idx,B_DRAW,3);
idx = BrushFind(2100);
BrushSet (idx,B_DRAW,3);
GameCommand (CMD_REFRESH);

}
else
{
DropObject(idx);
}
}


// Lift 2
func ActionObject_2130()
{
idx = ObjFind(2130);

	{
            Message1(10,4,"DIZZI VOSPOLJZOVALSAJ\nLIFTOM");
		MessagePop();

	y = PlayerGet(P_Y);
	y -= 130;
	PlayerSet(P_Y,y);
            
}
}


// PRISCEXLETS

func UseObject_6620( idx )
{
if(ObjGet(idx,O_ID)==101) 
{
Message1(5,4, "TEPERJ MIX MOWEXM\nPRODOLWIXTJ"); 
MessagePop();
Message2(16,8,"NACEX\nPUTECEXSTVIE!");
MessagePop();
InventorySub(idx);
idx = BrushFind(6600);
BrushSet (idx,B_DRAW,3);
idx = BrushFind(6610);
BrushSet (idx,B_DRAW,3);

idx = BrushFind(6680);
BrushSet (idx,B_DRAW,0);
idx = BrushFind(6690);
BrushSet (idx,B_DRAW,0);

idx = ObjFind(190);
ObjSet(idx,O_DISABLE,0);

GameCommand (CMD_REFRESH);

}
else
{
DropObject(idx);
}
}

//

func ActionObject_6620( idx )
{
	if(ObjGet(ObjFind(6620),O_STATUS)==0) // first time talk
	{
		Message2(3,8,"UBIRAYTESJ S\nNACEXY PLANETIX!");
		MessagePop();
		ObjSet(ObjFind(6620),O_STATUS,5); // advance the talk status
	}
	else // next time
	{
		// open the inventory dialog and let the player select an item
		idx = OpenDialogInventory();
		if(idx!=-1)
		{
			// if an item was selected, call the defaut use function
			// it will also call the UseObject callback of the item
			UseObject(idx); 
		}
	}
}



// Kovojr T

func UseObject_1093( idx )
{
if(ObjGet(idx,O_ID)==191) 
{
Message1(5,4, "DIZZI POLOWIXL\nTOLSTIXY KOVOJR\nNA OSTRIXE KOLJAJ"); 
MessagePop();

InventorySub(idx);
	idx = BrushFind(1091);
BrushSet (idx,B_DRAW,3);
GameCommand (CMD_REFRESH);

}
else
{
DropObject(idx);
}
}


// K 1

func ActionObject_5005()

	{
            Message1(10,4,"DIZZI UPAL\nV BEZDONNIXY KOLODETS");
		MessagePop();

	x = PlayerGet(P_X);
	x -= -50;
	PlayerSet(P_X,x);

      y = PlayerGet(P_Y);
	y -= -230;
	PlayerSet(P_Y,y);
          
}

// K 2

func ActionObject_5006()

	{
            Message1(10,4,"DIZZI UPAL\nV BEZDONNIXY KOLODETS");
		MessagePop();

	x = PlayerGet(P_X);
	x -= 50;
	PlayerSet(P_X,x);

y = PlayerGet(P_Y);
y -= 860;
PlayerSet(P_Y,y);

            
}


// SKAFANDR

func UseObject_1097( idx )
{
if(ObjGet(idx,O_ID)==160) 
{
Message1(5,4, "DIZZI NADEL\nSKAFANDR"); 
MessagePop();

InventorySub(idx);
idx = BrushFind(1098);
BrushSet (idx,B_DRAW,0);
GameCommand (CMD_REFRESH);

}
else
{
DropObject(idx);
}
}

// Kamenj

func UseObject_6002 ( idx )
{
if(ObjGet(idx,O_ID)==140)
{
Message1(5,4, "DIZZI PODLOWIXL\nKAMENJ");
MessagePop();

InventorySub(idx);

idx = BrushFind(6001);
BrushSet (idx,B_DRAW,3);

GameCommand (CMD_REFRESH);

}
else
{
DropObject(idx);
}
}


// TOJTAJ

func UseObject_17( idx )
{
if(ObjGet(idx,O_ID)==14) 
{
Message1(5,4, "SPASIBO!"); 
MessagePop();
InventorySub(idx);

idx = ObjFind(22);
ObjSet(idx,O_DISABLE,0);
idx = BrushFind(771);
BrushSet (idx,B_DRAW,3);
GameCommand (CMD_REFRESH);

}
else
{
DropObject(idx);
}
}

//

func ActionObject_17( idx )
{
	if(ObjGet(ObjFind(17),O_STATUS)==0) // first time talk
	{
		Message2(3,8,"MNE NUWNO\nUKOLOTJ PALETS");
		MessagePop();
            Message2(10,4,"ZAQEM?");
		MessagePop();
            Message2(3,8,"QTOBIX IZ NEGO\nPERESTALA TEQ\nKROVJ");
		MessagePop();

		ObjSet(ObjFind(17),O_STATUS,5); // advance the talk status
	}
	else // next time
	{
		// open the inventory dialog and let the player select an item
		idx = OpenDialogInventory();
		if(idx!=-1)
		{
			// if an item was selected, call the defaut use function
			// it will also call the UseObject callback of the item
			UseObject(idx); 
		}
	}
}


// LEV

func UseObject_11( idx )
{
if(ObjGet(idx,O_ID)==12) 
{
Message1(5,4, "S POMOCJUJ\nPINTSETA DIZZI"); 
MessagePop();
Message1(3,8, "VIXTACIL CIXP\nIZ LAPIX LJVA"); 
MessagePop();

InventorySub(idx);

idx = ObjFind(14);
ObjSet(idx,O_DISABLE,0);

GameCommand (CMD_REFRESH);

}
else
{
DropObject(idx);
}
}

//

func ActionObject_11( idx )
{
	if(ObjGet(ObjFind(11),O_STATUS)==0) // first time talk
	{
		Message2(3,8,"QTO SLUQILOSJ?");
		MessagePop();
            Message2(10,4,"ZLOY TROLJ\nTOLKNUL MENAJ");
		MessagePop();
            Message2(3,8,"V ROZOVIXY KUST");
		MessagePop();

		ObjSet(ObjFind(11),O_STATUS,5); // advance the talk status
	}
	else // next time
	{
		// open the inventory dialog and let the player select an item
		idx = OpenDialogInventory();
		if(idx!=-1)
		{
			// if an item was selected, call the defaut use function
			// it will also call the UseObject callback of the item
			UseObject(idx); 
		}
	}
}


// DVERJ

func UseObject_13( idx )
{
if(ObjGet(idx,O_ID)==18) 
{
Message1(5,4, "DIZZI OTKRIXL\nDVERJ KLUJQOM"); 
MessagePop();
InventorySub(idx);
idx = BrushFind(10);
BrushSet (idx,B_DRAW,0);

GameCommand (CMD_REFRESH);

}
else
{
DropObject(idx);
}
}


// TROLJ

func UseObject_21( idx )
{
if(ObjGet(idx,O_ID)==22) 
{
Message1(5,4, "DIZZI DAL\nAJBLOKO TROLUJ"); 
MessagePop();
InventorySub(idx);
idx = BrushFind(23);
BrushSet (idx,B_DRAW,0);
            idx = BrushFind(1022);
            BrushSet (idx,B_DRAW,0);
GameCommand (CMD_REFRESH);

}
else
{
DropObject(idx);
}
}


// KAMENJ

func UseObject_29( idx )
{
if(ObjGet(idx,O_ID)==25) 
{
Message1(5,4, "S POMOCJUJ LOMA\nDIZZI UBRAL"); 
MessagePop();
Message1(3,8, "S DOROGI\nTAJWOLIXY KAMENJ"); 
MessagePop();

InventorySub(idx);
idx = BrushFind(24);
BrushSet (idx,B_DRAW,0);

GameCommand (CMD_REFRESH);

}
else
{
DropObject(idx);
}
}


// Kovojr L 1

func UseObject_34( idx )
{
if(ObjGet(idx,O_ID)==195) 
{
Message1(5,4, "DIZZI VOSPOLJZOVALSAJ\nLETAUJCIM KOVROM"); 
MessagePop();

	x = PlayerGet(P_X);
	x -= -1940;
	PlayerSet(P_X,x);

      y = PlayerGet(P_Y);
	y -= 230;
	PlayerSet(P_Y,y);

GameCommand (CMD_REFRESH);

}
else
{
DropObject(idx);
}
}


// Lift 2
func ActionObject_827()
{
idx = ObjFind(827);

	{
            Message1(10,4,"DIZZI VOSPOLJZOVALSAJ\nLIFTOM");
		MessagePop();

	y = PlayerGet(P_Y);
	y -= 130;
	PlayerSet(P_Y,y);
            
}
}


// LODKA 2
func ActionObject_88()

{

Message1(10,4,"DIZZI VOSPOLJZOVALSAJ\nLODKOY");
MessagePop();

	x = PlayerGet(P_X);
	x -= -376;
	PlayerSet(P_X,x);

}


// LODKA 1

func ActionObject_89()

{

Message1(10,4,"DIZZI VOSPOLJZOVALSAJ\nLODKOY");
MessagePop();

	x = PlayerGet(P_X);
	x -= 376;
	PlayerSet(P_X,x);

}


// OKNO

func UseObject_298( idx )
{
if(ObjGet(idx,O_ID)==450) 
{
Message1(5,4, "DIZZI OTKRIXL\n OKNO KLUJQOM"); 
MessagePop();

InventorySub(idx);

idx = BrushFind(769);
BrushSet (idx,B_DRAW,0);

GameCommand (CMD_REFRESH);

}
else
{
DropObject(idx);
}
}


// VAMP

func UseObject_74( idx )
{
if(ObjGet(idx,O_ID)==79) 
{
Message1(5,4, "DIZZI SXEL QESNOK"); 
MessagePop();
InventorySub(idx);
idx = BrushFind(78);
BrushSet (idx,B_DRAW,0);
GameCommand (CMD_REFRESH);

}
else
{
DropObject(idx);
}
}


// Gnom
func ActionObject_72()
{
idx = ObjFind(72);

	{
            Message1(10,4,"AJ USTAL");
		MessagePop();

            ObjSet(idx,O_DISABLE,1);

            idx = ObjFind(71);
            ObjSet(idx,O_DISABLE,0);
}
}

// Rabota

func UseObject_77( idx )
{
if(ObjGet(idx,O_ID)==71) 
{
Message1(5,4, "DIZZI RASQISTIL\nZAVAL"); 
MessagePop();
InventorySub(idx);
idx = BrushFind(73);
BrushSet (idx,B_DRAW,3);
GameCommand (CMD_REFRESH);

}
else
{
DropObject(idx);
}
}


// DV

func UseObject_937( idx )
{
if(ObjGet(idx,O_ID)==973) 
{
Message1(5,4, "DIZZI RAZBIL\nDVERJ"); 
MessagePop();

InventorySub(idx);

idx = BrushFind(977);
BrushSet (idx,B_DRAW,3);

GameCommand (CMD_REFRESH);

}
else
{
DropObject(idx);
}
}


// DV T

func UseObject_1092( idx )
{
if(ObjGet(idx,O_ID)==190) 
{
Message1(5,4, "TUK-TUK"); 
MessagePop();

InventorySub(idx);
idx = BrushFind(1096);
BrushSet (idx,B_DRAW,0);

GameCommand (CMD_REFRESH);

GameCommand (CMD_REFRESH);

}
else
{
DropObject(idx);
}
}

//

func ActionObject_1092( idx )
{
	if(ObjGet(ObjFind(1092),O_STATUS)==0) // first time talk
	{
		Message2(5,8,"POSTUQI I VOYDI");
		MessagePop();

		ObjSet(ObjFind(1092),O_STATUS,5); // advance the talk status
	}
	else // next time
	{
		// open the inventory dialog and let the player select an item
		idx = OpenDialogInventory();
		if(idx!=-1)
		{
			// if an item was selected, call the defaut use function
			// it will also call the UseObject callback of the item
			UseObject(idx); 
		}
	}
}


// Kovojr L 2

func UseObject_624( idx )
{
if(ObjGet(idx,O_ID)==195) 
{
Message1(5,4, "DIZZI VOSPOLJZOVALSAJ\nLETAUJCIM KOVROM"); 
MessagePop();

	x = PlayerGet(P_X);
	x -= 20;
	PlayerSet(P_X,x);

y = PlayerGet(P_Y);
y -= 130;
PlayerSet(P_Y,y);

GameCommand (CMD_REFRESH);

}
else
{
DropObject(idx);
}
}


// BABUCKA 3

func ActionObject_493()
{
idx = ObjFind(493);
status = ObjGet(idx,O_STATUS);

	if(status==0)

	{
            Message1(10,4,"TIX NACOL\n30 MONET?");
		MessagePop();
		Message2(14,6,"NET ECOJ");
		MessagePop();
ObjSet(idx,O_STATUS,1);

}

        if(status==1)

{

Message1(10,4,"AJ NACOL 30 MONET\nI OTPRAVLAJUJSJ");
MessagePop();
Message1(5,4,"V SKAZOQNOE\nPUTECEXSTVIE!");
MessagePop();
Message1(10,4,"POZDRAVLAJUJ DIZZI!");
MessagePop();

}
}


// MON 1

func ActionObject_333()
{
idx = ObjFind(333);

	{
            Message1(10,4,"DVOYNIK DIZZI\nNE DAOJT EMU\nPOVERNUTJ RIXQAG");
		MessagePop();
           

}
}


// MON 2

func ActionObject_332()
{
idx = ObjFind(332);

	{
        Message1(10,4,"DIZZI POVERNUL\nRIXQAG");
		MessagePop();

ObjSet(idx,O_DISABLE,1);

idx = BrushFind(331);
BrushSet (idx,B_DRAW,3);

idx = BrushFind(330);
BrushSet (idx,B_DRAW,3);
GameCommand (CMD_REFRESH);
}
}

// SKAZ

func ActionObject_592()

{

Message1(10,4,"SKAZOQNOE PUTECEXSTVIE!");
MessagePop();

	x = PlayerGet(P_X);
	x -= 230;
	PlayerSet(P_X,x);

}


// END

func ActionObject_760()
{
idx = ObjFind(760);
status = ObjGet(idx,O_STATUS);

	if(status==0)

	{
            Message1(10,4,"AJ ECOJ NE NACOL\n30 MONET");
		MessagePop();

x = PlayerGet(P_X);
x -= -210;
PlayerSet(P_X,x);

y = PlayerGet(P_Y);
y -= 140;
PlayerSet(P_Y,y);
ObjSet(idx,O_STATUS,1);

}

        if(status==1)

{

Message1(5,4, "KONETS");
MessagePop();


            ObjSet(idx,O_DISABLE,1);

            idx = BrushFind(796);
            BrushSet (idx,B_DRAW,2);

GameCommand (CMD_REFRESH);


	y = PlayerGet(P_Y);
	y -= -200;
	PlayerSet(P_Y,y);

}
}


/////////////////////////////////////////////////////////////////////////////////
